@@ -130,7 +130,7 @@ void GetUSSD(int argc UNUSED, char *argv[])
 	GSM_Init(TRUE);
 
 	signal(SIGINT, interrupt);
-	fprintf(stderr, "%s\n", _("Press Ctrl+C to break..."));
+	fprintf(stderr, "%s\n", _("Press Ctrl+C to break…"));
 	fflush(stderr);
 
 	GSM_SetIncomingUSSDCallback(gsm, IncomingUSSD2, NULL);
@@ -602,7 +602,7 @@ void SendSaveDisplaySMS(int argc, char *argv[])
 				GSM_SetSendSMSStatusCallback(gsm, SendSMSStatus, NULL);
 
 				signal(SIGINT, interrupt);
-				fprintf(stderr, "%s\n", _("If you want break, press Ctrl+C..."));
+				fprintf(stderr, "%s\n", _("If you want break, press Ctrl+C…"));
 				fflush(stderr);
 			}
 
@@ -627,7 +627,7 @@ void SendSaveDisplaySMS(int argc, char *argv[])
 					SMSStatus = ERR_TIMEOUT;
 					error = GSM_SendSavedSMS(gsm, 0, sms->SMS[i].Location);
 					Print_Error(error);
-					printf("%s", _("....waiting for network answer"));
+					printf("%s", _("…waiting for network answer"));
 					fflush(stdout);
 
 					while (!gshutdown) {
@@ -642,7 +642,7 @@ void SendSaveDisplaySMS(int argc, char *argv[])
 			break;
 		case SMS_Send:
 			signal(SIGINT, interrupt);
-			fprintf(stderr, "%s\n", _("If you want break, press Ctrl+C..."));
+			fprintf(stderr, "%s\n", _("If you want break, press Ctrl+C…"));
 			fflush(stderr);
 
 			GSM_SetSendSMSStatusCallback(gsm, SendSMSStatus, NULL);
@@ -653,7 +653,7 @@ void SendSaveDisplaySMS(int argc, char *argv[])
 				SMSStatus = ERR_TIMEOUT;
 				error=GSM_SendSMS(gsm, &(sms->SMS[i]));
 				Print_Error(error);
-				printf("%s", _("....waiting for network answer"));
+				printf("%s", _("…waiting for network answer"));
 				fflush(stdout);
 
 				while (!gshutdown) {
