@@ -130,6 +130,8 @@ GSM_FeatureName AllFeatureNames[] = {
 	{"HUAWEI_INIT", F_HUAWEI_INIT},
 	{"ZTE_INIT", F_ZTE_INIT},
 	{"USSD_GSM_CHARSET", F_USSD_GSM_CHARSET},
+	{"SMS_SR", F_SMS_SR},
+	{"SMS_NO_SR", F_SMS_NO_SR},
 	{"", 0},
 };
 
@@ -955,7 +957,7 @@ GSM_PhoneModel allmodels[] = {
 	{"E162",	"E162",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, F_RESET_AFTER_TIMEOUT, F_HUAWEI_INIT, 0}},
 	{"E160G",	"E160G",	"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, F_RESET_AFTER_TIMEOUT, F_HUAWEI_INIT, 0}},
 	{"E162G",	"E162G",	"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, F_RESET_AFTER_TIMEOUT, F_HUAWEI_INIT, 0}},
-	{"E169",	"E169",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, F_RESET_AFTER_TIMEOUT, F_HUAWEI_INIT, 0}},
+	{"E169",	"E169",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_USSD_GSM_CHARSET, F_FOUR_DIGIT_YEAR, F_RESET_AFTER_TIMEOUT, F_HUAWEI_INIT, 0}},
 	{"E169G",	"E169G",	"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, F_RESET_AFTER_TIMEOUT, F_HUAWEI_INIT, 0}},
 	{"E171",	"E171",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, F_RESET_AFTER_TIMEOUT, F_HUAWEI_INIT, 0}},
 	{"E173",	"E173",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, F_RESET_AFTER_TIMEOUT, F_HUAWEI_INIT, 0}},
@@ -1006,6 +1008,10 @@ GSM_PhoneModel allmodels[] = {
 
 	/* Qualcomm */
 	{"HP un2420 Mobile Broadband Module", "un2420", "", {F_NO_STOP_CUSD, 0}},
+	
+	/* Sierra */
+	{"SL8084TR Product", "SL8084TR Product", "", {F_CPIN_NO_OK, 0}},
+	
 
 #endif
 #if defined(GSM_ENABLE_ATGEN) || defined(GSM_ENABLE_ALCATEL)
